@@ -1,47 +1,55 @@
-<?php  // $Id: excellib.class.php,v 1.12.2.4 2008/04/14 22:40:55 stronk7 Exp $
+<?php
 
-///////////////////////////////////////////////////////////////////////////
-//                                                                       //
-// NOTICE OF COPYRIGHT                                                   //
-//                                                                       //
-// Moodle - Modular Object-Oriented Dynamic Learning Environment         //
-//          http://moodle.com                                            //
-//                                                                       //
-// Copyright (C) 1999 onwards Martin Dougiamas     http://dougiamas.com  //
-//           (C) 2001-3001 Eloy Lafuente (stronk7) http://contiento.com  //
-//                                                                       //
-// This program is free software; you can redistribute it and/or modify  //
-// it under the terms of the GNU General Public License as published by  //
-// the Free Software Foundation; either version 2 of the License, or     //
-// (at your option) any later version.                                   //
-//                                                                       //
-// This program is distributed in the hope that it will be useful,       //
-// but WITHOUT ANY WARRANTY; without even the implied warranty of        //
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         //
-// GNU General Public License for more details:                          //
-//                                                                       //
-//          http://www.gnu.org/copyleft/gpl.html                         //
-//                                                                       //
-///////////////////////////////////////////////////////////////////////////
+// This file is part of Moodle - http://moodle.org/
+//
+// Moodle is free software: you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// Moodle is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.
 
-//setup.php icludes our hacked pear libs first
+/**
+ * excellib.class.php
+ *
+ * @copyright  (C) 2001-3001 Eloy Lafuente (stronk7) {@link http://contiento.com}
+ * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
+ * @package    core
+ * @subpackage lib
+ */
+
+defined('MOODLE_INTERNAL') || die();
+
+/** setup.php includes our hacked pear libs first */
 require_once 'Spreadsheet/Excel/Writer.php';
 
 /**
-* Define and operate over one Moodle Workbook.
-*
-* A big part of this class acts as a wrapper over the PEAR
-* Spreadsheet_Excel_Writer_Workbook and OLE libraries
-* maintaining Moodle functions isolated from underlying code.
-*/
+ * Define and operate over one Moodle Workbook.
+ *
+ * A big part of this class acts as a wrapper over the PEAR
+ * Spreadsheet_Excel_Writer_Workbook and OLE libraries
+ * maintaining Moodle functions isolated from underlying code.
+ *
+ * @copyright 1999 onwards Martin Dougiamas  {@link http://moodle.com}
+ * @license http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
+ * @package moodlecore
+ */
 class MoodleExcelWorkbook {
-
+    /** @var object */
     var $pear_excel_workbook;
+    /** @var bool */
     var $latin_output;
 
     /**
      * Constructs one Moodle Workbook.
      *
+     * @global object
      * @param string $filename The name of the file
      */
     function MoodleExcelWorkbook($filename) {
@@ -56,18 +64,19 @@ class MoodleExcelWorkbook {
             $this->latin_output = true;
         }
     /// Choose our temporary directory - see MDL-7176, found by paulo.matos
-        make_upload_directory('temp/excel', false);
-        $this->pear_excel_workbook->setTempDir($CFG->dataroot.'/temp/excel');
+        make_temp_directory('excel');
+        $this->pear_excel_workbook->setTempDir($CFG->tempdir.'/excel');
     }
 
     /**
      * Create one Moodle Worksheet
      *
      * @param string $name Name of the sheet
+     * @return object MoodleExcelWorksheet
      */
     function &add_worksheet($name = '') {
     /// Create the Moodle Worksheet. Returns one pointer to it
-        $ws =& new MoodleExcelWorksheet ($name, $this->pear_excel_workbook, $this->latin_output);
+        $ws = new MoodleExcelWorksheet ($name, $this->pear_excel_workbook, $this->latin_output);
         return $ws;
     }
 
@@ -78,10 +87,11 @@ class MoodleExcelWorkbook {
      *                          valid names are set_XXXX existing
      *                          functions without the set_ part
      *                          i.e: [bold]=1 for set_bold(1)...Optional!
+     * @return object MoodleExcelFormat
      */
     function &add_format($properties = array()) {
     /// Create the Moodle Format. Returns one pointer to it
-        $ft =& new MoodleExcelFormat ($this->pear_excel_workbook, $properties);
+        $ft = new MoodleExcelFormat ($this->pear_excel_workbook, $properties);
         return $ft;
     }
 
@@ -95,7 +105,7 @@ class MoodleExcelWorkbook {
     /**
      * Write the correct HTTP headers
      *
-     * @param string $name Name of the downloaded file
+     * @param string $filename Name of the downloaded file
      */
     function send($filename) {
         $this->pear_excel_workbook->send($filename);
@@ -103,15 +113,20 @@ class MoodleExcelWorkbook {
 }
 
 /**
-* Define and operate over one Worksheet.
-*
-* A big part of this class acts as a wrapper over the PEAR
-* Spreadsheet_Excel_Writer_Workbook and OLE libraries
-* maintaining Moodle functions isolated from underlying code.
-*/
+ * Define and operate over one Worksheet.
+ *
+ * A big part of this class acts as a wrapper over the PEAR
+ * Spreadsheet_Excel_Writer_Workbook and OLE libraries
+ * maintaining Moodle functions isolated from underlying code.
+ *
+ * @copyright 1999 onwards Martin Dougiamas  {@link http://moodle.com}
+ * @license http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
+ * @package moodlecore
+ */
 class MoodleExcelWorksheet {
-
+    /** @var object */
     var $pear_excel_worksheet;
+    /** @var bool Only if don't want to use latin (win1252) stronger output */
     var $latin_output;
 
     /**
@@ -119,13 +134,23 @@ class MoodleExcelWorksheet {
      *
      * @param string $filename The name of the file
      * @param object $workbook The internal PEAR Workbook onject we are creating
+     * @param bool $latin_output Only if don't want to use latin (win1252) stronger output
      */
     function MoodleExcelWorksheet($name, &$workbook, $latin_output=false) {
 
-    /// Internally, add one sheet to the workbook    
+        if (strlen($name) > 31) {
+            // Excel does not seem able to cope with sheet names > 31 chars.
+            // With $latin_output = false, it does not cope at all.
+            // With $latin_output = true it is supposed to work, but in our experience,
+            // it doesn't. Therefore, truncate in all circumstances.
+            $textlib = textlib_get_instance();
+            $name = $textlib->substr($name, 0, 31);
+        }
+
+    /// Internally, add one sheet to the workbook
         $this->pear_excel_worksheet =& $workbook->addWorksheet($name);
         $this->latin_output = $latin_output;
-    /// Set encoding to UTF-16LE 
+    /// Set encoding to UTF-16LE
         if (!$this->latin_output) { /// Only if don't want to use latin (win1252) stronger output
             $this->pear_excel_worksheet->setInputEncoding('UTF-16LE');
         }
@@ -184,6 +209,29 @@ class MoodleExcelWorksheet {
         $this->pear_excel_worksheet->writeUrl($row, $col, $url, $format);
     }
 
+    /**
+     * Write one date somewhere in the worksheet
+     * @param integer $row    Zero indexed row
+     * @param integer $col    Zero indexed column
+     * @param string  $date   The date to write in UNIX timestamp format
+     * @param mixed   $format The XF format for the cell
+     */
+    function write_date($row, $col, $date, $format=null) {
+    /// Calculate the internal PEAR format
+        $format = $this->MoodleExcelFormat2PearExcelFormat($format);
+    /// Convert the date to Excel format
+        $timezone = get_user_timezone_offset();
+        if ($timezone == 99) {
+            // system timezone offset in seconds
+            $offset = (int)date('Z');
+        } else {
+            $offset = (int)($timezone * HOURSECS * 2);
+        }
+        $value = ((usertime($date) + $offset) / 86400) + 25569;
+    /// Add  the date safely to the PEAR Worksheet
+        $this->pear_excel_worksheet->writeNumber($row, $col, $value, $format);
+    }
+
     /**
      * Write one formula somewhere in the worksheet
      *
@@ -221,6 +269,7 @@ class MoodleExcelWorksheet {
      * @param integer $col    Zero indexed column
      * @param mixed   $token  What we are writing
      * @param mixed   $format The XF format for the cell
+     * @return void
      */
     function write($row, $col, $token, $format=null) {
 
@@ -302,7 +351,7 @@ class MoodleExcelWorksheet {
     function hide_screen_gridlines() {
         $this->pear_excel_worksheet->hideScreenGridlines();
     }
-    
+
     /**
     * Insert a 24bit bitmap image in a worksheet.
     *
@@ -339,7 +388,7 @@ class MoodleExcelWorksheet {
     /**
      * Returns the PEAR Excel Format for one Moodle Excel Format
      *
-     * @param mixed MoodleExcelFormat object
+     * @param mixed $format MoodleExcelFormat object
      * @return mixed PEAR Excel Format object
      */
     function MoodleExcelFormat2PearExcelFormat($format) {
@@ -353,23 +402,28 @@ class MoodleExcelWorksheet {
 
 
 /**
-* Define and operate over one Format.
-*
-* A big part of this class acts as a wrapper over the PEAR
-* Spreadsheet_Excel_Writer_Workbook and OLE libraries
-* maintaining Moodle functions isolated from underlying code.
-*/
+ * Define and operate over one Format.
+ *
+ * A big part of this class acts as a wrapper over the PEAR
+ * Spreadsheet_Excel_Writer_Workbook and OLE libraries
+ * maintaining Moodle functions isolated from underlying code.
+ *
+ * @copyright 1999 onwards Martin Dougiamas  {@link http://moodle.com}
+ * @license http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
+ * @package moodlecore
+ */
 class MoodleExcelFormat {
-
+    /** @var object */
     var $pear_excel_format;
 
     /**
      * Constructs one Moodle Format.
      *
      * @param object $workbook The internal PEAR Workbook onject we are creating
+     * @param array $properties
      */
     function MoodleExcelFormat(&$workbook, $properties = array()) {
-    /// Internally, add one sheet to the workbook    
+    /// Internally, add one sheet to the workbook
         $this->pear_excel_format =& $workbook->addFormat();
     /// If we have something in the array of properties, compute them
         foreach($properties as $property => $value) {
@@ -604,5 +658,3 @@ class MoodleExcelFormat {
     }
 
 }
-
-?>
