@@ -1,4 +1,4 @@
-<?php  // $Id: field.class.php,v 1.14.2.3 2009/03/24 10:38:59 thepurpleblob Exp $
+<?php
 ///////////////////////////////////////////////////////////////////////////
 //                                                                       //
 // NOTICE OF COPYRIGHT                                                   //
@@ -26,17 +26,13 @@ class data_field_checkbox extends data_field_base {
 
     var $type = 'checkbox';
 
-    function data_field_checkbox($field=0, $data=0) {
-        parent::data_field_base($field, $data);
-    }
-
     function display_add_field($recordid=0) {
-        global $CFG;
+        global $CFG, $DB;
 
         $content = array();
 
         if ($recordid) {
-            $content = get_field('data_content', 'content', 'fieldid', $this->field->id, 'recordid', $recordid);
+            $content = $DB->get_field('data_content', 'content', array('fieldid'=>$this->field->id, 'recordid'=>$recordid));
             $content = explode('##', $content);
         } else {
             $content = array();
@@ -69,43 +65,38 @@ class data_field_checkbox extends data_field_base {
     }
 
     function display_search_field($value='') {
-        global $CFG;
-        if (is_array($value)){
-            $content     = $value['checked'];
-            $allrequired = $value['allrequired'] ? 'checked = "checked"' : '';
+        global $CFG, $DB;
+
+        if (is_array($value)) {
+            $content = $value['checked'];
+            $allrequired = $value['allrequired'] ? true : false;
         } else {
-            $content     = array();
-            $allrequired = '';
+            $content = array();
+            $allrequired = false;
         }
 
-        static $c = 0;
-
         $str = '';
-
         $found = false;
         foreach (explode("\n",$this->field->param1) as $checkbox) {
             $checkbox = trim($checkbox);
-            $str .= '<input type="checkbox" value="' . s($checkbox) . '"';
 
-            if (in_array(addslashes($checkbox), $content)) {
-                // Selected by user.
-                $str .= ' checked = "checked"';
+            if (in_array($checkbox, $content)) {
+                $str .= html_writer::checkbox('f_'.$this->field->id.'[]', s($checkbox), true, $checkbox);
+            } else {
+                $str .= html_writer::checkbox('f_'.$this->field->id.'[]', s($checkbox), false, $checkbox);
             }
-            $str .= 'name="f_'.$this->field->id.'[]">' . $checkbox . '<br />';
             $found = true;
         }
         if (!$found) {
-            // oh, nothing to search for
             return '';
         }
-        $str .= '&nbsp;<input name="f_'.$this->field->id.'_allreq" id="f_'.$this->field->id.'_allreq'.$c.'" type="checkbox" '.$allrequired.'/>';
-        $str .= '<label for="f_'.$this->field->id.'_allreq'.$c.'">'.get_string('selectedrequired', 'data').'</label>';
-        $c++;
+
+        $str .= html_writer::checkbox('f_'.$this->field->id.'_allreq', null, $allrequired, get_string('selectedrequired', 'data'));
         return $str;
     }
-    
+
     function parse_search_field() {
-        $selected    = optional_param('f_'.$this->field->id, array(), PARAM_NOTAGS);
+        $selected    = optional_param_array('f_'.$this->field->id, array(), PARAM_NOTAGS);
         $allrequired = optional_param('f_'.$this->field->id.'_allreq', 0, PARAM_BOOL);
         if (empty($selected)) {
             // no searching
@@ -113,49 +104,66 @@ class data_field_checkbox extends data_field_base {
         }
         return array('checked'=>$selected, 'allrequired'=>$allrequired);
     }
-    
+
     function generate_sql($tablealias, $value) {
+        global $DB;
+
+        static $i=0;
+        $i++;
+        $name = "df_checkbox_{$i}_";
+        $params = array();
+        $varcharcontent = $DB->sql_compare_text("{$tablealias}.content", 255);
+
         $allrequired = $value['allrequired'];
         $selected    = $value['checked'];
 
         if ($selected) {
             $conditions = array();
+            $j=0;
             foreach ($selected as $sel) {
+                $j++;
+                $xname = $name.$j;
                 $likesel = str_replace('%', '\%', $sel);
                 $likeselsel = str_replace('_', '\_', $likesel);
-                $conditions[] = "({$tablealias}.fieldid = {$this->field->id} AND ({$tablealias}.content = '$sel'
-                                                                               OR {$tablealias}.content LIKE '$likesel##%'
-                                                                               OR {$tablealias}.content LIKE '%##$likesel'
-                                                                               OR {$tablealias}.content LIKE '%##$likesel##%'))";
+                $conditions[] = "({$tablealias}.fieldid = {$this->field->id} AND ({$varcharcontent} = :{$xname}a
+                                                                               OR {$tablealias}.content LIKE :{$xname}b
+                                                                               OR {$tablealias}.content LIKE :{$xname}c
+                                                                               OR {$tablealias}.content LIKE :{$xname}d))";
+                $params[$xname.'a'] = $sel;
+                $params[$xname.'b'] = "$likesel##%";
+                $params[$xname.'c'] = "%##$likesel";
+                $params[$xname.'d'] = "%##$likesel##%";
             }
             if ($allrequired) {
-                return " (".implode(" AND ", $conditions).") ";
+                return array(" (".implode(" AND ", $conditions).") ", $params);
             } else {
-                return " (".implode(" OR ", $conditions).") ";
+                return array(" (".implode(" OR ", $conditions).") ", $params);
             }
         } else {
-            return " ";
+            return array(" ", array());
         }
     }
 
-
     function update_content($recordid, $value, $name='') {
-        $content = new object();
+        global $DB;
+
+        $content = new stdClass();
         $content->fieldid = $this->field->id;
         $content->recordid = $recordid;
         $content->content = $this->format_data_field_checkbox_content($value);
 
-        if ($oldcontent = get_record('data_content','fieldid', $this->field->id, 'recordid', $recordid)) {
+        if ($oldcontent = $DB->get_record('data_content', array('fieldid'=>$this->field->id, 'recordid'=>$recordid))) {
             $content->id = $oldcontent->id;
-            return update_record('data_content', $content);
+            return $DB->update_record('data_content', $content);
         } else {
-            return insert_record('data_content', $content);
+            return $DB->insert_record('data_content', $content);
         }
     }
 
     function display_browse_field($recordid, $template) {
+        global $DB;
 
-       if ($content = get_record('data_content', 'fieldid', $this->field->id, 'recordid', $recordid)) {
+        if ($content = $DB->get_record('data_content', array('fieldid'=>$this->field->id, 'recordid'=>$recordid))) {
             if (empty($content->content)) {
                 return false;
             }
@@ -189,8 +197,9 @@ class data_field_checkbox extends data_field_base {
             if ($key === 'xxx') {
                 continue;
             }
-            if (!in_array(stripslashes($val), $options)) {
+            if (!in_array($val, $options)) {
                 continue;
+
             }
             $vals[] = $val;
         }
@@ -203,4 +212,4 @@ class data_field_checkbox extends data_field_base {
     }
 
 }
-?>
+
